==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mainmenu/translations/mainmenu_es_UY.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_UY">
<context>
    <name>RazorMainMenu</name>
    <message>
        <location filename="../razormainmenu.cpp" line="171"/>
        <source>Leave</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="14"/>
        <source>Razor Main Menu settings</source>
        <translation>Configuración del Menú Principal Razor</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Mostrar etiqueta</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="45"/>
        <source>Button text</source>
        <translation>Etiqueta del botón</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="65"/>
        <location filename="../razormainmenuconfiguration.ui" line="71"/>
        <source>Menu file</source>
        <translation>Archivo de menú</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="85"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="85"/>
        <source>Choose menu file</source>
        <translation>Seleccionar archivo de menú</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="85"/>
        <source>Menu files (*.menu)</source>
        <translation>Archivos de menú (*.menu)</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mainmenu/translations/mainmenu_es_UY.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_UY" version="2.0">
<context>
    <name>RazorMainMenu</name>
    <message>
        <source>Leave</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <source>Razor Main Menu settings</source>
        <translation>Configuración del Menú Principal Razor</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation>Mostrar etiqueta</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation>Etiqueta del botón</translation>
    </message>
    <message>
        <source>Menu file</source>
        <translation>Archivo de menú</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Keyboard Shortcut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Click the button to record shortcut:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose menu file</source>
        <translation>Seleccionar archivo de menú</translation>
    </message>
    <message>
        <source>Menu files (*.menu)</source>
        <translation>Archivos de menú (*.menu)</translation>
    </message>
</context>
</TS>
